:mod:`art.preprocessing.expectation_over_transformation`
========================================================
.. automodule:: art.preprocessing.expectation_over_transformation

EOT Image Center Crop - PyTorch
-------------------------------
.. autoclass:: EoTImageCenterCropPyTorch
   :members:
   :special-members:

EOT Image Rotation - TensorFlow V2
----------------------------------
.. autoclass:: EoTImageRotationTensorFlow
   :members:
   :special-members:

EOT Image Rotation - PyTorch
----------------------------
.. autoclass:: EoTImageRotationPyTorch
   :members:
   :special-members:

EOT Brightness - PyTorch
------------------------
.. autoclass:: EoTBrightnessPyTorch
   :members:
   :special-members:

EOT Brightness - TensorFlow V2
----------------------------------
.. autoclass:: EoTBrightnessTensorFlow
   :members:
   :special-members:

EOT Contrast - PyTorch
----------------------
.. autoclass:: EoTContrastPyTorch
   :members:
   :special-members:

EOT Contrast - TensorFlow V2
----------------------------
.. autoclass:: EoTContrastTensorFlow
   :members:
   :special-members:

EOT Gaussian Noise - PyTorch
----------------------------
.. autoclass:: EoTGaussianNoisePyTorch
   :members:
   :special-members:

EOT Gaussian Noise - TensorFlow V2
----------------------------------
.. autoclass:: EoTGaussianNoiseTensorFlow
   :members:
   :special-members:

EOT Shot Noise - PyTorch
------------------------
.. autoclass:: EoTShotNoisePyTorch
   :members:
   :special-members:

EOT Shot Noise - TensorFlow V2
------------------------------
.. autoclass:: EoTShotNoiseTensorFlow
   :members:
   :special-members:

EOT Zoom Blur - PyTorch
-----------------------
.. autoclass:: EoTZoomBlurPyTorch
   :members:
   :special-members:

EOT Zoom Blur - TensorFlow V2
----------------------------------
.. autoclass:: EoTZoomBlurTensorFlow
   :members:
   :special-members:
